@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2018 Intel Corporation
+// Copyright (c) 2017-2020 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -107,7 +107,7 @@ struct CURBEData {
         struct {
             mfxU32  SliceMacroblockHeightMinusOne:8;
             mfxU32  PictureHeightMinusOne:8;
-            mfxU32  PictureWidth:8;
+            mfxU32  PictureWidthMinusOne:8;
             mfxU32  MBZ11:8;
         };
     };
