@@ -873,48 +873,6 @@ mfxStatus VideoPAK_PAK::RunFramePAKCheck(
     return mfxSts;
 }
 
-static mfxStatus CopyRawSurfaceToVideoMemory(VideoCORE &    core,
-                                        MfxVideoParam const & video,
-                                        mfxFrameSurface1 *  src_sys,
-                                        mfxMemId            dst_d3d,
-                                        mfxHDL&             handle)
-{
-    MFX_CHECK_NULL_PTR1(src_sys);
-
-    mfxExtOpaqueSurfaceAlloc const * extOpaq = GetExtBuffer(video);
-    MFX_CHECK(extOpaq, MFX_ERR_NOT_FOUND);
-
-    mfxFrameData d3dSurf {};
-
-    if (video.IOPattern == MFX_IOPATTERN_IN_SYSTEM_MEMORY ||
-        (video.IOPattern == MFX_IOPATTERN_IN_OPAQUE_MEMORY && (extOpaq->In.Type & MFX_MEMTYPE_SYSTEM_MEMORY)))
-    {
-        mfxFrameData sysSurf = src_sys->Data;
-        d3dSurf.MemId = dst_d3d;
-
-        FrameLocker lock2(&core, sysSurf, true);
-
-        MFX_CHECK_NULL_PTR1(sysSurf.Y)
-        {
-            MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_HOTSPOTS, "Copy input (sys->d3d)");
-            MFX_CHECK_STS(CopyFrameDataBothFields(&core, d3dSurf, sysSurf, video.mfx.FrameInfo));
-        }
-
-        MFX_CHECK_STS(lock2.Unlock());
-    }
-    else
-    {
-        d3dSurf.MemId =  src_sys->Data.MemId;
-    }
-
-    if (video.IOPattern != MFX_IOPATTERN_IN_OPAQUE_MEMORY)
-       MFX_CHECK_STS(core.GetExternalFrameHDL(d3dSurf.MemId, &handle))
-    else
-       MFX_CHECK_STS(core.GetFrameHDL(d3dSurf.MemId, &handle));
-
-    return MFX_ERR_NONE;
-}
-
 
 mfxStatus VideoPAK_PAK::Close(void)
 {
@@ -936,7 +894,7 @@ mfxStatus VideoPAK_PAK::ProcessAndCheckNewParameters(
 {
     MFX_CHECK_NULL_PTR1(newParIn);
 
-    InheritDefaultValues(m_video, newPar, newParIn);
+    InheritDefaultValues(m_video, newPar, m_caps, newParIn);
 
     mfxStatus checkStatus = CheckVideoParam(newPar, m_caps, m_core->IsExternalFrameAllocator(), m_currentPlatform, m_currentVaType);
     MFX_CHECK(checkStatus != MFX_WRN_PARTIAL_ACCELERATION, MFX_ERR_INVALID_VIDEO_PARAM);
