@@ -53,11 +53,7 @@
 #endif
 
 #if defined (MFX_ENABLE_H265_VIDEO_ENCODE)
-#if defined(MFX_ENABLE_HEVCEHW_REFACTORING)
 #include "hevcehw_disp.h"
-#else
-#include "mfx_h265_encode_hw.h"
-#endif
 #endif
 
 #if defined (MFX_ENABLE_VP9_VIDEO_ENCODE)
@@ -65,7 +61,6 @@
 #endif
 
 #if defined(MFX_VA)
-#include "mfx_h265_fei_encode_hw.h"
 #include <libmfx_core_interface.h>
 #endif
 
@@ -258,7 +253,6 @@ static const CodecId2Handlers codecId2Handlers =
         {
             // .primary =
             {
-#if defined(MFX_ENABLE_HEVCEHW_REFACTORING_FEI)
                 // .ctor =
                 [](VideoCORE* core, mfxStatus* mfxRes)
                 -> VideoENCODE*
@@ -273,18 +267,6 @@ static const CodecId2Handlers codecId2Handlers =
                 // .queryIOSurf =
                 [](mfxSession session, mfxVideoParam *par, mfxFrameAllocRequest *request)
                 { return HEVCEHW::QueryIOSurf(session->m_pCORE.get(), par, request, true); }
-#else
-                // .ctor =
-                [](VideoCORE* core, mfxStatus* mfxRes)
-                -> VideoENCODE*
-                { return new MfxHwH265FeiEncode::H265FeiEncode_HW(core, mfxRes); },
-                // .query =
-                [](mfxSession s, mfxVideoParam *in, mfxVideoParam *out)
-                { return MfxHwH265FeiEncode::H265FeiEncode_HW::Query(s->m_pCORE.get(), in, out); },
-                // .queryIOSurf =
-                [](mfxSession s, mfxVideoParam *par, mfxFrameAllocRequest *request)
-                { return MfxHwH265FeiEncode::H265FeiEncode_HW::QueryIOSurf(s->m_pCORE.get(), par, request); }
-#endif //defined(MFX_ENABLE_HEVCEHW_REFACTORING_FEI)
             }
         }
     },
@@ -299,7 +281,6 @@ static const CodecId2Handlers codecId2Handlers =
         {
             // .primary =
             {
-#if defined(MFX_ENABLE_HEVCEHW_REFACTORING)
                 // .ctor =
                 [](VideoCORE* core, mfxStatus* mfxRes)
                 -> VideoENCODE*
@@ -314,18 +295,6 @@ static const CodecId2Handlers codecId2Handlers =
                 // .queryIOSurf =
                 [](mfxSession session, mfxVideoParam *par, mfxFrameAllocRequest *request)
                 { return HEVCEHW::QueryIOSurf(session->m_pCORE.get(), par, request); }
-#else // defined(MFX_ENABLE_HEVCEHW_REFACTORING)
-                // .ctor =
-                [](VideoCORE* core, mfxStatus* mfxRes)
-                -> VideoENCODE*
-                { return new MfxHwH265Encode::MFXVideoENCODEH265_HW(core, mfxRes); },
-                // .query =
-                [](mfxSession s, mfxVideoParam *in, mfxVideoParam *out)
-                { return MfxHwH265Encode::MFXVideoENCODEH265_HW::Query(s->m_pCORE.get(), in, out); },
-                // .queryIOSurf =
-                [](mfxSession s, mfxVideoParam *par, mfxFrameAllocRequest *request)
-                { return MfxHwH265Encode::MFXVideoENCODEH265_HW::QueryIOSurf(s->m_pCORE.get(), par, request); }
-#endif // defined(MFX_ENABLE_HEVCEHW_REFACTORING)
             },
             // .fallback =
             {
