@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2020 Intel Corporation
+// Copyright (c) 2018-2021 Intel Corporation
 // 
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -167,7 +167,7 @@ namespace
         sps.ip_period       = pExecuteBuffers->m_GOPRefDist;
         // For VBR maxBitrate should be used as sps parameter, target bitrate has no place in sps, only in BRC
         sps.bits_per_second = (winSps.RateControlMethod == MFX_RATECONTROL_VBR && winSps.MaxBitRate > winSps.bit_rate) ?
-                winSps.MaxBitRate : winSps.bit_rate;
+            winSps.MaxBitRate : winSps.bit_rate;
         if (winSps.vbv_buffer_size)
         {
             sps.vbv_buffer_size = winSps.vbv_buffer_size;
@@ -244,7 +244,7 @@ namespace
     {
         assert(pExecuteBuffers);
         const ENCODE_SET_PICTURE_PARAMETERS_MPEG2 & winPps = pExecuteBuffers->m_pps;
-        
+
         pps.picture_type = ConvertCodingTypeMFX2VAAPI(winPps.picture_coding_type);
         pps.temporal_reference = winPps.temporal_reference;
         pps.vbv_delay = winPps.vbv_delay;
@@ -331,10 +331,12 @@ VAAPIEncoder::VAAPIEncoder(VideoCORE* core)
     , m_codedbufISize(0)
     , m_codedbufPBSize(0)
     , m_pMiscParamsFps(0)
+    , m_pMiscParamsBrc(0)
     , m_pMiscParamsQuality(0)
     , m_pMiscParamsSeqInfo(0)
     , m_pMiscParamsSkipFrame(0)
     , m_miscParamFpsId(VA_INVALID_ID)
+    , m_miscParamBrcId(VA_INVALID_ID)
     , m_miscParamQualityId(VA_INVALID_ID)
     , m_miscParamSeqInfoId(VA_INVALID_ID)
     , m_miscParamSkipFrameId(VA_INVALID_ID)
@@ -465,6 +467,10 @@ mfxStatus VAAPIEncoder::Init(ExecuteBuffers* pExecuteBuffers, mfxU32 numRefFrame
     Zero((VAEncMiscParameterFrameRate &)m_pMiscParamsFps->data);
     m_pMiscParamsFps->type = VAEncMiscParameterTypeFrameRate;
 
+    m_pMiscParamsBrc = (VAEncMiscParameterBuffer*)new mfxU8[sizeof(VAEncMiscParameterRateControl) + sizeof(VAEncMiscParameterBuffer)];
+    Zero((VAEncMiscParameterRateControl &)m_pMiscParamsBrc->data);
+    m_pMiscParamsBrc->type = VAEncMiscParameterTypeRateControl;
+
     m_pMiscParamsQuality = (VAEncMiscParameterBuffer*)new mfxU8[sizeof(VAEncMiscParameterEncQuality) + sizeof(VAEncMiscParameterBuffer)];
     Zero((VAEncMiscParameterEncQuality &)m_pMiscParamsQuality->data);
     m_pMiscParamsQuality->type = (VAEncMiscParameterType)VAEncMiscParameterTypeEncQuality;
@@ -927,13 +933,17 @@ mfxStatus VAAPIEncoder::FillSlices(ExecuteBuffers* pExecuteBuffers)
 
 mfxStatus VAAPIEncoder::FillMiscParameterBuffer(ExecuteBuffers* pExecuteBuffers)
 {
-    VAEncMiscParameterFrameRate  & miscFps      = (VAEncMiscParameterFrameRate  &)m_pMiscParamsFps->data;
-    VAEncMiscParameterEncQuality & miscQuality  = (VAEncMiscParameterEncQuality &)m_pMiscParamsQuality->data;
+    VAEncMiscParameterFrameRate   & miscFps     = (VAEncMiscParameterFrameRate   &)m_pMiscParamsFps->data;
+    VAEncMiscParameterRateControl & miscBrc     = (VAEncMiscParameterRateControl &)m_pMiscParamsBrc->data;
+    VAEncMiscParameterEncQuality  & miscQuality = (VAEncMiscParameterEncQuality  &)m_pMiscParamsQuality->data;
 
     VAStatus                      vaSts;
 
     PackMfxFrameRate(pExecuteBuffers->m_FrameRateExtN, pExecuteBuffers->m_FrameRateExtD, miscFps.framerate);
 
+    miscBrc.bits_per_second = pExecuteBuffers->m_sps.MaxBitRate * 1000;
+    miscBrc.target_percentage = pExecuteBuffers->m_sps.MaxBitRate ? uint32_t(pExecuteBuffers->m_sps.bit_rate * 100. / pExecuteBuffers->m_sps.MaxBitRate) : 0;
+
     miscQuality.PanicModeDisable = pExecuteBuffers->m_bDisablePanicMode ? 1 : 0;
 
     mfxStatus sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_miscParamFpsId);
@@ -948,6 +958,21 @@ mfxStatus VAAPIEncoder::FillMiscParameterBuffer(ExecuteBuffers* pExecuteBuffers)
         &m_miscParamFpsId);
     MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
+    sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_miscParamBrcId);
+    MFX_CHECK_STS(sts);
+
+    if (pExecuteBuffers->m_sps.RateControlMethod == MFX_RATECONTROL_VBR)
+    {
+        vaSts = vaCreateBuffer(m_vaDisplay,
+            m_vaContextEncode,
+            VAEncMiscParameterBufferType,
+            sizeof(VAEncMiscParameterRateControl) + sizeof(VAEncMiscParameterBuffer),
+            1,
+            m_pMiscParamsBrc,
+            &m_miscParamBrcId);
+        MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    }
+
     sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_miscParamQualityId);
     MFX_CHECK_STS(sts);
 
@@ -1310,6 +1335,9 @@ mfxStatus VAAPIEncoder::Execute(ExecuteBuffers* pExecuteBuffers, mfxU32 funcId,
     if (m_miscParamFpsId != VA_INVALID_ID)
         configBuffers.push_back(m_miscParamFpsId);
 
+    if (m_miscParamBrcId != VA_INVALID_ID)
+        configBuffers.push_back(m_miscParamBrcId);
+
     if (m_miscParamQualityId != VA_INVALID_ID)
         configBuffers.push_back(m_miscParamQualityId);
 
@@ -1510,6 +1538,8 @@ mfxStatus VAAPIEncoder::Close()
     MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_HOTSPOTS, "VAAPIEncoder::Close");
     delete [] (mfxU8 *)m_pMiscParamsFps;
     m_pMiscParamsFps = 0;
+    delete [] (mfxU8 *)m_pMiscParamsBrc;
+    m_pMiscParamsBrc = 0;
     delete [] (mfxU8 *)m_pMiscParamsQuality;
     m_pMiscParamsQuality = 0;
     delete [] m_pMiscParamsSeqInfo;
@@ -1535,6 +1565,9 @@ mfxStatus VAAPIEncoder::Close()
     sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_miscParamFpsId);
     std::ignore = MFX_STS_TRACE(sts);
 
+    sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_miscParamBrcId);
+    std::ignore = MFX_STS_TRACE(sts);
+
     sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_miscParamQualityId);
     std::ignore = MFX_STS_TRACE(sts);
 
@@ -1663,7 +1696,9 @@ mfxStatus VAAPIEncoder::FillBSBuffer(mfxU32 nFeedback,mfxU32 nBitstream, mfxBits
     //------------------------------------------
     // (1) mapping feedbackNumber -> surface & bs
     bool isFound = false;
+#if !VA_CHECK_VERSION(1,9,0)
     VASurfaceID waitSurface;
+#endif
     mfxU32 waitIdxBs;
     mfxU32 indxSurf;
     mfxU32 bitstreamSize = 0;
@@ -1676,7 +1711,9 @@ mfxStatus VAAPIEncoder::FillBSBuffer(mfxU32 nFeedback,mfxU32 nBitstream, mfxBits
 
         if (currentFeedback.number == nFeedback)
         {
+#if !VA_CHECK_VERSION(1,9,0)
             waitSurface = currentFeedback.surface;
+#endif
             waitIdxBs   = currentFeedback.idxBs;
             isFound  = true;
 
