@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2019 Intel Corporation
+// Copyright (c) 2017-2020 Intel Corporation
 // 
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -121,8 +121,11 @@ mfxStatus MFXVC1DecCommon::Query(VideoCORE* core, mfxVideoParam *in, mfxVideoPar
                 (in->IOPattern & MFX_IOPATTERN_OUT_OPAQUE_MEMORY))
             {
                 uint32_t mask = in->IOPattern & 0xf0;
-                if (mask != MFX_IOPATTERN_OUT_VIDEO_MEMORY || mask != MFX_IOPATTERN_OUT_SYSTEM_MEMORY || mask != MFX_IOPATTERN_OUT_OPAQUE_MEMORY)
+                if ((mask == MFX_IOPATTERN_OUT_SYSTEM_MEMORY) || (mask == MFX_IOPATTERN_OUT_VIDEO_MEMORY) ||
+                    (mask == MFX_IOPATTERN_OUT_OPAQUE_MEMORY))
                     out->IOPattern = in->IOPattern;
+                else
+                    sts = MFX_ERR_UNSUPPORTED;
             }
 
             if (in->Protected)
