@@ -28,24 +28,38 @@
 namespace MFX_VPX_Utility
 
 {
-    inline mfxU32 GetMaxWidth(mfxU32 codecId)
+    inline mfxU32 GetMaxWidth(mfxU32 codecId, eMFXHWType hwType)
     {
         switch (codecId)
         {
         case MFX_CODEC_VP8:
-        case MFX_CODEC_VP9:
             return 4096;
+        case MFX_CODEC_VP9:
+            if (hwType < MFX_HW_KBL)
+                return 4096;
+            return 16384;
+#if defined(MFX_ENABLE_AV1_VIDEO_DECODE)
+        case MFX_CODEC_AV1:
+            return 16384;
+#endif
         default: return 0;
         }
     }
 
-    inline mfxU32 GetMaxHeight(mfxU32 codecId)
+    inline mfxU32 GetMaxHeight(mfxU32 codecId, eMFXHWType hwType)
     {
         switch (codecId)
         {
         case MFX_CODEC_VP8:
+            return 4096;
         case MFX_CODEC_VP9:
-            return 2304;
+            if (hwType < MFX_HW_KBL)
+                return 4096;
+            return 16384;
+#if defined(MFX_ENABLE_AV1_VIDEO_DECODE)
+        case MFX_CODEC_AV1:
+            return 16384;
+#endif
         default: return 0;
         }
     }
@@ -56,6 +70,9 @@ namespace MFX_VPX_Utility
         {
         case MFX_CODEC_VP8: return profile <= MFX_PROFILE_VP8_3;
         case MFX_CODEC_VP9: return profile <= MFX_PROFILE_VP9_3;
+#if defined(MFX_ENABLE_AV1_VIDEO_DECODE)
+        case MFX_CODEC_AV1: return profile <= MFX_PROFILE_AV1_PRO;
+#endif
         default: return false;
         }
     }
@@ -88,6 +105,14 @@ namespace MFX_VPX_Utility
                 break;
             }
 
+#if defined(MFX_ENABLE_AV1_VIDEO_DECODE)
+            if (codecId == MFX_CODEC_AV1)
+            {
+                p_out->mfx.CodecLevel = p_in->mfx.CodecLevel;
+                p_out->mfx.FilmGrain = p_in->mfx.FilmGrain;
+            }
+#endif
+
             if (p_in->mfx.NumThread < 128)
                 p_out->mfx.NumThread = p_in->mfx.NumThread;
 
@@ -199,12 +224,12 @@ namespace MFX_VPX_Utility
             if (!p_in->mfx.FrameInfo.ChromaFormat && !(!p_in->mfx.FrameInfo.FourCC && !p_in->mfx.FrameInfo.ChromaFormat))
                 sts = MFX_ERR_UNSUPPORTED;
 
-            if (p_in->mfx.FrameInfo.Width % 16 == 0 && p_in->mfx.FrameInfo.Width <= GetMaxWidth(codecId))
+            if (p_in->mfx.FrameInfo.Width % 16 == 0 && p_in->mfx.FrameInfo.Width <= GetMaxWidth(codecId, core->GetHWType()))
                 p_out->mfx.FrameInfo.Width = p_in->mfx.FrameInfo.Width;
             else
                 sts = MFX_ERR_UNSUPPORTED;
 
-            if (p_in->mfx.FrameInfo.Height % 16 == 0 && p_in->mfx.FrameInfo.Height <= GetMaxHeight(codecId))
+            if (p_in->mfx.FrameInfo.Height % 16 == 0 && p_in->mfx.FrameInfo.Height <= GetMaxHeight(codecId, core->GetHWType()))
                 p_out->mfx.FrameInfo.Height = p_in->mfx.FrameInfo.Height;
             else
                 sts = MFX_ERR_UNSUPPORTED;
@@ -242,6 +267,16 @@ namespace MFX_VPX_Utility
                 sts = MFX_ERR_UNSUPPORTED;
             }
 
+            switch (p_in->mfx.FrameInfo.PicStruct)
+            {
+            case MFX_PICSTRUCT_UNKNOWN:
+            case MFX_PICSTRUCT_PROGRESSIVE:
+                p_out->mfx.FrameInfo.PicStruct = p_in->mfx.FrameInfo.PicStruct;
+                break;
+            default:
+                sts = MFX_ERR_UNSUPPORTED;
+                break;
+            }
 
             if (p_in->mfx.ExtendedPicStruct)
                 sts = MFX_ERR_UNSUPPORTED;
@@ -286,6 +321,14 @@ namespace MFX_VPX_Utility
             p_out->mfx.CodecProfile = 1;
             p_out->mfx.CodecLevel = 1;
 
+#if defined(MFX_ENABLE_AV1_VIDEO_DECODE)
+            if (codecId == MFX_CODEC_AV1)
+            {
+                p_out->mfx.CodecLevel = MFX_LEVEL_AV1_2;
+                p_out->mfx.FilmGrain = 1;
+            }
+#endif
+
             p_out->mfx.NumThread = 1;
 
             p_out->AsyncDepth = 1;
@@ -428,10 +471,14 @@ namespace MFX_VPX_Utility
 
         p_request->NumFrameMin += p_params->AsyncDepth ? p_params->AsyncDepth : MFX_AUTO_ASYNC_DEPTH_VALUE;
 
+#if defined(MFX_ENABLE_AV1_VIDEO_DECODE)
+        if ((p_params->mfx.CodecId == MFX_CODEC_AV1) && p_params->mfx.FilmGrain)
+            p_request->NumFrameMin = 2 * p_request->NumFrameMin; // we need two output surfaces for each frame when film_grain is applied
+#endif
         // Increase minimum number by one
         // E.g., decoder unlocks references in sync part (NOT async), so in order to free some surface
         // application need an additional surface to call DecodeFrameAsync()
-        p_request->NumFrameMin += 1;
+        p_request->NumFrameMin += 2;
 
         p_request->NumFrameSuggested = p_request->NumFrameMin;
 
