@@ -929,9 +929,6 @@ mfxStatus GetPipelineList(
     mfxInfoVPP*   par = NULL;
     mfxFrameInfo* srcFrameInfo = NULL;
     mfxFrameInfo* dstFrameInfo = NULL;
-    mfxU16  srcW = 0, dstW = 0;
-    mfxU16  srcH = 0, dstH = 0;
-    //mfxU32  lenList = 0;
     mfxStatus sts = MFX_ERR_NONE;
 
     MFX_CHECK_NULL_PTR1( videoParam );
@@ -1031,14 +1028,6 @@ mfxStatus GetPipelineList(
         pipelineList.push_back(MFX_EXTBUFF_VPP_LSHIFT_OUT);
     }
 
-    /* [Resize] FILTER */
-    VPP_GET_REAL_WIDTH(  srcFrameInfo, srcW);
-    VPP_GET_REAL_HEIGHT( srcFrameInfo, srcH);
-
-    /* OUT */
-    VPP_GET_REAL_WIDTH( dstFrameInfo, dstW);
-    VPP_GET_REAL_HEIGHT(dstFrameInfo, dstH);
-
     { //resize or cropping
         pipelineList.push_back(MFX_EXTBUFF_VPP_RESIZE);
     }
