@@ -20,6 +20,11 @@
 
 #include "umc_defs.h"
 
+#if defined(MFX_VA) && !defined MFX_DEC_VIDEO_POSTPROCESS_DISABLE
+// For setting SFC surface
+#include "umc_va_video_processing.h"
+#endif
+
 #include "mfx_umc_alloc_wrapper.h"
 #include "mfx_common.h"
 #include "libmfx_core.h"
@@ -429,6 +434,33 @@ UMC::Status mfx_UMC_FrameAllocator::GetFrameHandle(UMC::FrameMemID memId, void *
     return UMC::UMC_OK;
 }
 
+static mfxStatus SetSurfaceForSFC(VideoCORE& core, mfxFrameSurface1& surf)
+{
+#if defined(MFX_VA) && !defined MFX_DEC_VIDEO_POSTPROCESS_DISABLE
+    // Set surface for SFC
+    UMC::VideoAccelerator * va = nullptr;
+
+    core.GetVA((mfxHDL*)&va, MFX_MEMTYPE_FROM_DECODE);
+    MFX_CHECK_HDL(va);
+
+    auto video_processing_va = va->GetVideoProcessingVA();
+
+    if (video_processing_va && core.GetVAType() == MFX_HW_VAAPI)
+    {
+        mfxHDL surfHDL = {};
+        mfxStatus sts = core.GetExternalFrameHDL(surf.Data. MemId, &surfHDL, false);
+
+        MFX_CHECK_STS(sts);
+        video_processing_va->SetOutputSurface(surfHDL);
+    }
+#else
+    std::ignore = core;
+    std::ignore = surf;
+#endif
+
+    return MFX_ERR_NONE;
+}
+
 UMC::Status mfx_UMC_FrameAllocator::Alloc(UMC::FrameMemID *pNewMemID, const UMC::VideoDataInfo * info, uint32_t a_flags)
 {
     UMC::AutomaticUMCMutex guard(m_guard);
@@ -502,6 +534,11 @@ UMC::Status mfx_UMC_FrameAllocator::Alloc(UMC::FrameMemID *pNewMemID, const UMC:
                 return UMC::UMC_ERR_FAILED;
 
             m_extSurfaces[m_curIndex].isUsed = true;
+
+            if (m_sfcVideoPostProcessing)
+            {
+                SetSurfaceForSFC(*m_pCore, *m_extSurfaces[index].FrameSurface);
+            }
         }
     }
 
@@ -711,12 +748,14 @@ mfxStatus mfx_UMC_FrameAllocator::SetCurrentMFXSurface(mfxFrameSurface1 *surf, b
         return MFX_ERR_MORE_SURFACE;
 
     // check input surface
+    if (!(m_sfcVideoPostProcessing && (surf->Info.FourCC != m_surface_info.FourCC)))// if csc is done via sfc, will not do below checks
+    {
+        if ((surf->Info.BitDepthLuma ? surf->Info.BitDepthLuma : 8) != (m_surface_info.BitDepthLuma ? m_surface_info.BitDepthLuma : 8))
+            return MFX_ERR_INVALID_VIDEO_PARAM;
 
-    if ((surf->Info.BitDepthLuma ? surf->Info.BitDepthLuma : 8) != (m_surface_info.BitDepthLuma ? m_surface_info.BitDepthLuma : 8))
-        return MFX_ERR_INVALID_VIDEO_PARAM;
-
-    if ((surf->Info.BitDepthChroma ? surf->Info.BitDepthChroma : 8) != (m_surface_info.BitDepthChroma ? m_surface_info.BitDepthChroma : 8))
-        return MFX_ERR_INVALID_VIDEO_PARAM;
+        if ((surf->Info.BitDepthChroma ? surf->Info.BitDepthChroma : 8) != (m_surface_info.BitDepthChroma ? m_surface_info.BitDepthChroma : 8))
+            return MFX_ERR_INVALID_VIDEO_PARAM;
+    }
 
     if (   surf->Info.FourCC == MFX_FOURCC_P010
         || surf->Info.FourCC == MFX_FOURCC_P210
@@ -788,6 +827,7 @@ mfxStatus mfx_UMC_FrameAllocator::SetCurrentMFXSurface(mfxFrameSurface1 *surf, b
                 m_extSurfaces[m_curIndex].FrameSurface = surf;
                 break;
             }
+
             if ( (NULL != m_extSurfaces[i].FrameSurface) &&
                   (0 == m_extSurfaces[i].FrameSurface->Data.Locked) &&
                   (m_extSurfaces[i].FrameSurface->Data.MemId == surf->Data.MemId) &&
@@ -798,7 +838,23 @@ mfxStatus mfx_UMC_FrameAllocator::SetCurrentMFXSurface(mfxFrameSurface1 *surf, b
                 m_extSurfaces[m_curIndex].FrameSurface = surf;
                 break;
             }
-        } // for (mfxU32 i = 0; i < m_extSurfaces.size(); i++)
+        }
+
+        // Still not found. It may happen if decoder gets 'surf' surface which on app size belongs to
+        // a pool bigger than m_extSurfaces/m_frameDataInternal pools which decoder is aware.
+        if (m_curIndex == -1)
+        {
+            for (mfxU32 i = 0; i < m_extSurfaces.size(); i++)
+            {
+                // So attemping to find an expired slot in m_extSurfaces
+                if (!m_extSurfaces[i].isUsed && (0 == m_frameDataInternal.GetSurface(i).Data.Locked))
+                {
+                    m_curIndex = i;
+                    m_extSurfaces[m_curIndex].FrameSurface = surf;
+                    break;
+                }
+            }
+        }
     }
     else
     {
