@@ -50,7 +50,8 @@ void H265BaseBitstream::Reset(uint8_t * const pb, const uint32_t maxsize)
     m_pbs       = (uint32_t*)pb;
     m_pbsBase   = (uint32_t*)pb;
     m_bitOffset = 31;
-    m_maxBsSize    = maxsize;
+    m_maxBsSize = maxsize;
+    m_tailBsSize = 0;
 
 } // void Reset(uint8_t * const pb, const uint32_t maxsize)
 
@@ -61,6 +62,7 @@ void H265BaseBitstream::Reset(uint8_t * const pb, int32_t offset, const uint32_t
     m_pbsBase   = (uint32_t*)pb;
     m_bitOffset = offset;
     m_maxBsSize = maxsize;
+    m_tailBsSize = 0;
 
 } // void Reset(uint8_t * const pb, int32_t offset, const uint32_t maxsize)
 
@@ -115,6 +117,7 @@ bool H265BaseBitstream::More_RBSP_Data()
         return false;
 
     // get top bit, it can be "rbsp stop" bit
+    CheckBitsLeft(1);
     GetNBits(m_pbs, m_bitOffset, 1, code);
 
     // get remain bits, which is less then byte
@@ -122,6 +125,7 @@ bool H265BaseBitstream::More_RBSP_Data()
 
     if(tmp)
     {
+        CheckBitsLeft(tmp);
         GetNBits(m_pbs, m_bitOffset, tmp, code);
         if ((code << (8 - tmp)) & 0x7f)    // most sig bit could be rbsp stop bit
         {
