@@ -444,6 +444,8 @@ Status MJPEGVideoDecoderMFX_HW::GetFrameHW(MediaDataEx* in)
                 return UMC_ERR_FAILED;
 
             jerr = m_decBase->ParseSOS(JO_READ_HEADER);
+            if (m_decBase->m_curr_comp_no != m_decBase->m_curr_scan->ncomps-1)
+                return UMC_ERR_INVALID_STREAM;
             if(JPEG_OK != jerr)
             {
                 if (JPEG_ERR_BUFF == jerr)
@@ -721,7 +723,8 @@ Status MJPEGVideoDecoderMFX_HW::PackHeaders(MediaData* src, JPEG_DECODE_SCAN_PAR
 
         if(!bistreamData)
             return UMC_ERR_DEVICE_FAILED;
-
+        if(obtainedScanParams->DataLength > (uint32_t)compBufBs->GetBufferSize())
+            return UMC_ERR_INVALID_STREAM;
         std::copy(ptr + obtainedScanParams->DataOffset, ptr + obtainedScanParams->DataOffset + obtainedScanParams->DataLength, bistreamData);
     }
 
