@@ -1,4 +1,4 @@
-// Copyright (c) 2019 Intel Corporation
+// Copyright (c) 2020 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -96,6 +96,8 @@ namespace UMC_MPEG2_DECODER
         void PackQmatrix(const MPEG2DecoderFrameInfo&) override;
         // Pack slice parameters
         void PackSliceParams(const MPEG2Slice&, uint32_t) override;
+        // Pack gpu priority
+        void PackPriorityParams();
 
     private:
         void CreateSliceDataBuffer(const MPEG2DecoderFrameInfo&);
