@@ -366,7 +366,6 @@ Status VC1VideoDecoder::StartCodesProcessing(uint8_t*   pBStream,
 {
     MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_HOTSPOTS, "VC1VideoDecoder::StartCodesProcessing");
     Status umcRes = UMC_OK;
-    uint32_t readSize = 0;
     uint32_t UnitSize;
     VC1Status sts = VC1_OK;
     while ((*pValues != 0x0D010000)&&
@@ -385,19 +384,17 @@ Status VC1VideoDecoder::StartCodesProcessing(uint8_t*   pBStream,
             SwapData(m_dataBuffer, mfx::align2_value(UnitSize));
             m_pContext->m_bitstream.pBitstream = (uint32_t*)m_dataBuffer + 1; //skip start code
         }
-        readSize += UnitSize;
         m_pContext->m_bitstream.bitOffset  = 31;
         switch (*pValues)
         {
         case 0x0F010000:
-            bool isFPSChange;
             VC1Context context;
             size_t alignment;
            umcRes =  UMC_ERR_NOT_ENOUGH_DATA;
             context = *m_pContext;
             sts = SequenceLayer(&context);
             VC1_TO_UMC_CHECK_STS(sts);
-            isFPSChange = GetFPS(&context);
+            GetFPS(&context);
             alignment = (context.m_seqLayerHeader.INTERLACE)?32:16;
 
 
@@ -458,7 +455,6 @@ Status VC1VideoDecoder::StartCodesProcessing(uint8_t*   pBStream,
     if (((0x0D010000) == *pValues) && m_decoderInitFlag)// we have frame to decode
     {
         UnitSize = (uint32_t)(m_pCurrentIn->GetBufferSize() - *pOffsets);
-        readSize += UnitSize;
         m_pContext->m_pBufferStart = ((uint8_t*)m_frameData->GetDataPointer() + *pOffsets); //skip start code
         if (!IsDataPrepare)
         {
@@ -973,6 +969,12 @@ Status VC1VideoDecoder::GetStartCodes (uint8_t* pDataPointer,
             b = a & 0x00FFFFFF;
         }
 
+        // check small bitstream
+        if (stCodes->count == 0 && readBufSize < 4)
+        {
+            return UMC_ERR_NOT_ENOUGH_DATA;
+        }
+
         //check end of read buffer
         if(readPos < (readBuf + readBufSize - 1))
         {
@@ -1161,8 +1163,6 @@ Status VC1VideoDecoder::GetStartCodes (uint8_t* pDataPointer,
 
 void VC1VideoDecoder::GetFrameSize(MediaData* in)
 {
-    int32_t frameSize = 0;
-    uint8_t* ptr = m_pContext->m_pBufferStart;
     uint32_t i = 0;
     uint32_t* offset = m_pContext->m_Offsets;
     uint32_t* value = m_pContext->m_values;
@@ -1183,17 +1183,6 @@ void VC1VideoDecoder::GetFrameSize(MediaData* in)
             m_pContext->m_FrameSize = offset[i];
         }
     }
-    else
-    {
-        if ((*m_pContext->m_bitstream.pBitstream&0xFF) == 0xC5) // sequence header
-            frameSize = 36; // size of seq header for .rcv format
-        else
-        {
-            frameSize  = ((*(ptr))<<24) + ((*(ptr + 1))<<16) + ((*(ptr + 2))<<8) + *(ptr + 3);
-            frameSize &= 0x0fffffff;
-            frameSize += 8;
-        }
-    }
 }
 
 Status VC1VideoDecoder::VC1DecodeFrame(MediaData* , VideoData* )
