@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2019 Intel Corporation
+// Copyright (c) 2018-2020 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -1042,12 +1042,37 @@ STRUCT(mfxExtLAControl,
 
 )
 
+STRUCT(mfxQPandMode,
+    FIELD_T(mfxU8,  QP)
+    FIELD_T(mfxU16, Mode)
+)
+
 STRUCT(mfxExtMBQP,
     FIELD_S(mfxExtBuffer, Header)
     FIELD_T(mfxU32      , NumQPAlloc)
     FIELD_T(mfxU8*      , QP)
 )
 
+STRUCT(mfxExtInsertHeaders,
+    FIELD_S(mfxExtBuffer, Header)
+    FIELD_T(mfxU16, SPS)
+    FIELD_T(mfxU16, PPS)
+)
+
+
+STRUCT(mfxExtEncoderIPCMArea_area,
+    FIELD_T(mfxU32, Left    )
+    FIELD_T(mfxU32, Top     )
+    FIELD_T(mfxU32, Right   )
+    FIELD_T(mfxU32, Bottom  )
+)
+
+STRUCT(mfxExtEncoderIPCMArea,
+    FIELD_S(mfxExtBuffer, Header)
+    FIELD_T(mfxU16      , NumArea)
+    FIELD_T(mfxExtEncoderIPCMArea_area*, Areas)
+)
+
 STRUCT(mfxExtChromaLocInfo,
     FIELD_S(mfxExtBuffer, Header)
     FIELD_T(mfxU16      , ChromaLocInfoPresentFlag)
@@ -1383,3 +1408,36 @@ STRUCT(mfxExtVppMctf,
 )
 #endif
 #endif
+
+#if (MFX_VERSION >= 1034)
+STRUCT(mfxAV1FilmGrainPoint,
+    FIELD_T(mfxU8, Value)
+    FIELD_T(mfxU8, Scaling)
+)
+
+STRUCT(mfxExtAV1FilmGrainParam,
+    FIELD_S(mfxExtBuffer, Header)
+    FIELD_T(mfxU16, FilmGrainFlags)
+    FIELD_T(mfxU16, GrainSeed)
+    FIELD_T(mfxU8, RefIdx)
+    FIELD_T(mfxI8, NumYPoints)
+    FIELD_T(mfxI8, NumCbPoints)
+    FIELD_T(mfxI8, NumCrPoints)
+    FIELD_S(mfxAV1FilmGrainPoint, PointY)
+    FIELD_S(mfxAV1FilmGrainPoint, PointCb)
+    FIELD_S(mfxAV1FilmGrainPoint, PointCr)
+    FIELD_T(mfxI8, GrainScalingMinus8)
+    FIELD_T(mfxU8, ArCoeffLag)
+    FIELD_T(mfxU8, ArCoeffsYPlus128)
+    FIELD_T(mfxU8, ArCoeffsCbPlus128)
+    FIELD_T(mfxU8, ArCoeffsCrPlus128)
+    FIELD_T(mfxU8, ArCoeffShiftMinus6)
+    FIELD_T(mfxU8, GrainScaleShift)
+    FIELD_T(mfxU8, CbMult)
+    FIELD_T(mfxU8, CbLumaMult)
+    FIELD_T(mfxU16, CbOffset)
+    FIELD_T(mfxU8, CrMult)
+    FIELD_T(mfxU8, CrLumaMult)
+    FIELD_T(mfxU16, CrOffset)
+)
+#endif
