@@ -32,7 +32,7 @@ class drmRenderer;
 class DRMLibVA : public CLibVA
 {
 public:
-    DRMLibVA(int type = MFX_LIBVA_DRM);
+    DRMLibVA(const std::string& devicePath = "", int type = MFX_LIBVA_DRM);
     virtual ~DRMLibVA(void);
 
     inline int getFD() { return m_fd; }
