@@ -34,16 +34,16 @@ private:
     FEI_EncodeInterface& operator= (const FEI_EncodeInterface& other_encode); // forbidden
 
 public:
-    MFXVideoSession*  m_pmfxSession;
-    MFXVideoENCODE*   m_pmfxENCODE;
-    mfxEncodeCtrl     m_encodeControl;
-    mfxVideoParam     m_videoParams;
-    mfxU32            m_allocId;
-    bufList*          m_pExtBuffers;
-    AppConfig*        m_pAppConfig;
-    mfxBitstream      m_mfxBS;
-    mfxSyncPoint      m_SyncPoint;
-    bool              m_bSingleFieldMode;
+    MFXVideoSession*      m_pmfxSession;
+    MFXVideoENCODE*       m_pmfxENCODE;
+    mfxEncodeCtrl         m_encodeControl;
+    MfxVideoParamsWrapper m_videoParams;
+    mfxU32                m_allocId;
+    bufList*              m_pExtBuffers;
+    AppConfig*            m_pAppConfig;
+    mfxBitstreamWrapper   m_mfxBS;
+    mfxSyncPoint          m_SyncPoint;
+    bool                  m_bSingleFieldMode;
 
     /* Bitstream writer */
     CSmplBitstreamWriter m_FileWriter;
@@ -61,8 +61,6 @@ public:
     FILE* m_pRepackStat_out;
 #endif
 
-    std::vector<mfxExtBuffer*> m_InitExtParams;
-
     /* Temporary memory to speed up computations */
     std::vector<mfxI16> m_tmpForMedian;
     std::vector<mfxExtFeiPreEncMV::mfxExtFeiPreEncMVMB> m_tmpForReading;
@@ -100,7 +98,7 @@ public:
         return m_pmfxENCODE->QueryIOSurf(&m_videoParams, request);
     }
 
-    mfxVideoParam* GetCommonVideoParams()
+    MfxVideoParamsWrapper* GetCommonVideoParams()
     {
         return &m_videoParams;
     }
