@@ -1,5 +1,5 @@
 /******************************************************************************\
-Copyright (c) 2005-2019, Intel Corporation
+Copyright (c) 2005-2020, Intel Corporation
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
@@ -21,16 +21,8 @@ or https://software.intel.com/en-us/media-client-solutions-support.
 
 #if !defined(_WIN32) && !defined(_WIN64)
 
-#include "logger.h"
-#include <string>
-#include <stdio.h>
-#include <stdlib.h>
-
 #include <va/va.h>
 
-#define DCL_USE_DEPRECATED_OPENCL_1_1_APIS
-#include <CL/cl.h>
-#include <CL/opencl.h>
 #include <CL/cl_va_api_media_sharing_intel.h>
 
 #include "opencl_filter.h"
